@@ -473,6 +473,21 @@ class Users(_defaults_.Defaults):
 		}
 		self.__verification_codes__.save()
 
+		# html vars.
+		for from_, to_ in [
+			"$DOMAIN",self.domain,
+			"$USERNAME",user.username,
+			"$EMAIL",user,email,
+			"$CODE",code,
+			"$IP",ip,
+			"$TIMESTAMP",Date().timestamp,
+		]:
+			html = html.replace(from_, to_)
+
+		# html colors.
+		for key,value in self.template_data["COLORS"]:
+			html = html.replace("$"+key.upper(), value)
+
 		# send email.
 		if Defaults.options.log_level >= 1:
 			Response.log(f"Sending [{mode}] code to user [{user.username}], email [{user.email}].")
@@ -513,9 +528,11 @@ class Users(_defaults_.Defaults):
 		fail = False
 		try: self.__verification_codes__[mode]
 		except: self.__verification_codes__[mode] = {}
-		try: success = self.__verification_codes__[mode][user.email]["attempts"] > 0 and str(self.__verification_codes__[mode][user.email]["code"]) == str(code)
+		try: 
+			decreased = date.decrease(date.timestamp, format=date.timestamp_format, minutes=5)
+			outdated = self.__verification_codes__[mode][user.email]["stamp"] <= Date(timestamp=decreased, format=date.timestamp_format):
+			success = not outdated and self.__verification_codes__[mode][user.email]["attempts"] > 0 and str(self.__verification_codes__[mode][user.email]["code"]) == str(code)
 		except KeyError: fail = True
-
 		# handle.
 		if fail: 
 			return Response.error("Incorrect verification code.")
